## Core-SDK (Dalpha-ai 라이브러리) 

### Introduction 
- 달파 AI 팀 내부에서 개발한 라이브러리로, 자주 사용되는 AI 모델들을 빠르고 편리하게 사용하는 목적으로 만들어진 python library, package입니다.
- 현재는 Classifier Train & Inference / Zero-Shot Classifier / Feedback Classifier를 지원하며, 추후에는 Clip training / Vector similarity search / Detector 등등을 지원할 예정입니다.

### Update
****v0.3.1****
- FeedbackClassifier 업데이트
- ImageClassifier 전처리 관련 에러 수정
- Pillow image 열 때  exif_tranpose 적용

### Installation

```
#### GPU 
pip install dalpha-ai
#### CPU
pip install dalpha-ai-cpu
```

### QuickStart

`` examples/HowToStart.ipynb ``
